@@ -1,7 +1,7 @@
 g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
                      timethreshold = c(5,10), acc.metric = "ENMO", desiredtz="Europe/London",constrain2range = TRUE) {
   #==============================================================
-  inbed = function(angle, k =60, perc = 0.1, inbedthreshold = 15, bedblocksize = 30, outofbedsize = 60, ws3 = 5, constrain2range = FALSE) {
+  sptwindow_HDCZA = function(angle, k =60, perc = 0.1, inbedthreshold = 15, bedblocksize = 30, outofbedsize = 60, ws3 = 5, constrain2range = FALSE) {
     medabsdi = function(angle) {
       angvar = stats::median(abs(diff(angle))) #50th percentile, do not use mean because that will be outlier dependent
       return(angvar)
@@ -63,7 +63,38 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
     tib.threshold = pp
     invisible(list(lightsout=lightsout,lightson=lightson,tib.threshold=tib.threshold))
   }
-  
+  dstime_handling_check = function(tmpTIME=tmpTIME,inbedout=inbedout,tz=c(),calc_lightson=c(),calc_lightsout=c()) {
+    time_lightsout =iso8601chartime2POSIX(tmpTIME[inbedout$lightsout],tz=tz)
+    time_lightson =iso8601chartime2POSIX(tmpTIME[inbedout$lightson],tz=tz)
+    time_lightson_hr = as.numeric(format(time_lightson, format = "%H"))
+    time_lightsout_hr = as.numeric(format(time_lightsout, format = "%H"))
+    t0 = as.numeric(format(iso8601chartime2POSIX(tmpTIME[1],tz=tz), format = "%H"))
+    t1 = as.numeric(format(iso8601chartime2POSIX(tmpTIME[length(tmpTIME)],tz=tz), format = "%H"))
+    if (is.na(t1) == TRUE | is.na(t0) == TRUE) { 
+      # if timestamp is stored in POSIX format (older versions of GGIR prior 2017)
+      # for example when milestone data generated by old packages is now processed
+      # then this part of the code is to facilitate consistency
+      time_lightsout =as.POSIXlt(tmpTIME[inbedout$lightsout],origin="1970-01-01",tz=tz)
+      time_lightson =as.POSIXlt(tmpTIME[inbedout$lightson],origin="1970-01-01",tz=tz)
+      time_lightson_hr = as.numeric(format(time_lightson, format = "%H"))
+      time_lightsout_hr = as.numeric(format(time_lightsout, format = "%H"))
+      t0 = as.numeric(format(as.POSIXlt(tmpTIME[1],origin="1970-01-01",tz=tz), format = "%H"))
+      t1 = as.numeric(format(as.POSIXlt(tmpTIME[length(tmpTIME)],origin="1970-01-01",tz=tz), format = "%H"))
+    }
+    Nhoursdata = floor(length(tmpTIME) / (3600/ws3))
+    delta_t1_t0 = (t1+24) - t0
+    if (length(time_lightson_hr) > 0 & length(time_lightsout_hr) > 0) {
+      if (Nhoursdata > (delta_t1_t0 + 0.1) &  # time has moved backward (autumn)  so lightson also needs to move backward
+          (time_lightson_hr > 1 | time_lightson_hr < 12) & (time_lightsout_hr < 1 | time_lightsout_hr > 12)) { #extra DST hour not recognized
+        calc_lightson = calc_lightson - 1
+      } else if (Nhoursdata + 0.1 < delta_t1_t0 &  # time has moved forward (spring) so lightson also needs to move forward
+                 (time_lightson_hr > 1 | time_lightson_hr < 12) & (time_lightsout_hr < 1 | time_lightsout_hr > 12)) { #missing DST hour not recognized
+        calc_lightson = calc_lightson + 1
+      }
+    }
+    
+    return(calc_lightson)
+  }
   #==================================================
   # get variables  
   D = IMP$metashort
@@ -170,10 +201,14 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
         #------------------------------------------------------------------
         # calculate time in bed, because this will be used by g.part4 if sleeplog is not available
         tmpANGLE = angle[qqq1:qqq2]
-        inbedout = inbed(tmpANGLE,ws3=ws3,constrain2range=constrain2range)
+        tmpTIME = time[qqq1:qqq2]
+        inbedout = sptwindow_HDCZA(tmpANGLE,ws3=ws3,constrain2range=constrain2range)
         if (length(inbedout$lightson) > 0 & length(inbedout$lightsout) > 0) {
           lightson[1] = inbedout$lightson
           lightsout[1] = inbedout$lightsout
+          lightson[1] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
+                                              tz=desiredtz,calc_lightson=lightson[1],
+                                              calc_lightsout=lightsout[1])
           tib.threshold[1] = inbedout$tib.threshold
         }
         
@@ -230,14 +265,16 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
           L5list[j] = L5
           # calculate time in bed, because this will be used by g.part4 if sleeplog is not available
           tmpANGLE = angle[qqq1:qqq2]
-          inbedout = inbed(tmpANGLE,ws3=ws3,constrain2range=constrain2range)
+          tmpTIME = time[qqq1:qqq2]
+          inbedout = sptwindow_HDCZA(tmpANGLE,ws3=ws3,constrain2range=constrain2range)
           if (length(inbedout$lightson) != 0 & length(inbedout$lightsout) != 0) {
             lightson[j] = (inbedout$lightson / (3600/ ws3)) + 12
             lightsout[j] = (inbedout$lightsout / (3600/ ws3)) + 12
+            lightson[j] = dstime_handling_check(tmpTIME=tmpTIME,inbedout=inbedout,
+                                                tz=desiredtz,calc_lightson=lightson[j],
+                                                calc_lightsout=lightsout[j])
             tib.threshold[j] = inbedout$tib.threshold
           }
-          
-          
         }
         detection.failed = FALSE      
       }
@@ -255,5 +292,6 @@ g.sib.det = function(M,IMP,I,twd=c(-12,12),anglethreshold = 5,
     tib.threshold = c()
     detection.failed = TRUE
   }
+  
   invisible(list(output = metatmp,detection.failed=detection.failed,L5list=L5list,lightson =lightson,lightsout=lightsout,tib.threshold=tib.threshold))
 }
